%global _hardened_build 1

Name: pdns-recursor
Version: 3.7.3
Release: 1%{?dist}
Summary: Modern, advanced and high performance recursing/non authoritative name server
Group: System Environment/Daemons
License: GPLv2
URL: http://powerdns.com
Source0: http://downloads.powerdns.com/releases/%{name}-%{version}.tar.bz2
Patch0: pdns-recursor-fixmakefile.patch
Patch1: pdns-recursor-disable-secpoll.patch

Provides: powerdns-recursor = %{version}-%{release}
BuildRequires: boost-devel
BuildRequires: lua-devel
BuildRequires: systemd-units
BuildRequires: hostname

Requires(pre): shadow-utils
Requires(post): systemd-sysv
Requires(post): systemd-units
Requires(preun): systemd-units
Requires(postun): systemd-units

%description
PowerDNS Recursor is a non authoritative/recursing DNS server. Use this
package if you need a dns cache for your network.

%prep
%setup -q
%patch0 -p1 -b .fixmakefile
%patch1 -p1 -b .disable-secpoll

%build
%configure
LUA=1 LUA_CPPFLAGS_CONFIG= LUA_LIBS_CONFIG=-llua OPTFLAGS="%{optflags}" LDFLAGS="%{?__global_ldflags}" make %{?_smp_mflags}

%install
make install DESTDIR=%{buildroot} CONFIGDIR="%{_sysconfdir}/%{name}"
chmod 0755 %{buildroot}/%{_bindir}/rec_control
chmod 0755 %{buildroot}/%{_sbindir}/pdns_recursor
# install systemd unit file
%{__install} -D -p -m 644 contrib/systemd-pdns-recursor.service %{buildroot}%{_unitdir}/%{name}.service

%{__mv} %{buildroot}%{_sysconfdir}/%{name}/recursor.conf{-dist,}

# add pdns user and group to top of configfile
sed -i '1i\setuid=pdns-recursor' %{buildroot}%{_sysconfdir}/%{name}/recursor.conf
sed -i '2i\setgid=pdns-recursor' %{buildroot}%{_sysconfdir}/%{name}/recursor.conf

%pre
getent group pdns-recursor > /dev/null || groupadd -r pdns-recursor
getent passwd pdns-recursor > /dev/null || \
    useradd -r -g pdns-recursor -d / -s /sbin/nologin \
    -c "PowerDNS Recursor user" pdns-recursor
exit 0

%post
%systemd_post pdns-recursor.service

%preun
%systemd_preun pdns-recursor.service

%postun
%systemd_postun_with_restart pdns-recursor.service

%triggerun -- pdns-recursor < 3.3-4
# Save the current service runlevel info
# User must manually run systemd-sysv-convert --apply pdns-recursor
# to migrate them to systemd targets
/usr/bin/systemd-sysv-convert --save pdns-recursor >/dev/null 2>&1 ||:

# Run these because the SysV package being removed won't do them
/sbin/chkconfig --del pdns-recursor >/dev/null 2>&1 || :
/bin/systemctl try-restart pdns-recursor.service >/dev/null 2>&1 || :

%files
%{_bindir}/rec_control
%{_sbindir}/pdns_recursor
%{_mandir}/man1/pdns_recursor.1.gz
%{_mandir}/man1/rec_control.1.gz
%{_unitdir}/pdns-recursor.service
%dir %{_sysconfdir}/%{name}
%config(noreplace) %{_sysconfdir}/%{name}/recursor.conf
%doc COPYING README

%changelog
* Wed Jun 10 2015 Morten Stevens <mstevens@imt-systems.com> - 3.7.3-1
- Update to 3.7.3

* Mon Apr 27 2015 Morten Stevens <mstevens@imt-systems.com> - 3.7.2-1
- Update to 3.7.2
- CVE-2015-1868

* Tue Feb 17 2015 Morten Stevens <mstevens@imt-systems.com> - 3.7.1-1
- Update to 3.7.1
- Disable security status polling by default

* Fri Oct 31 2014 Morten Stevens <mstevens@imt-systems.com> - 3.6.2-1
- Update to 3.6.2
- Enable security status polling

* Wed Sep 10 2014 Morten Stevens <mstevens@imt-systems.com> - 3.6.1-1
- Update to 3.6.1
- CVE-2014-3614 (#1139251)

* Fri Jun 20 2014 Morten Stevens <mstevens@imt-systems.com> - 3.6.0-1
- Update to 3.6.0

* Sat Jun 07 2014 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 3.6.0-0.2.rc1
- Rebuilt for https://fedoraproject.org/wiki/Fedora_21_Mass_Rebuild

* Fri May 30 2014 Morten Stevens <mstevens@imt-systems.com> - 3.6.0-0.1.rc1
- Update to 3.6.0-rc1

* Fri May 23 2014 Petr Machata <pmachata@redhat.com> - 3.5.3-3
- Rebuild for boost 1.55.0

* Mon Feb 10 2014 Morten Stevens <mstevens@imt-systems.com> - 3.5.3-2
- Add upstream patch to fix rhbz#1063305

* Tue Sep 17 2013 Morten Stevens <mstevens@imt-systems.com> - 3.5.3-1
- Update to 3.5.3

* Sat Aug 03 2013 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 3.5.2-4
- Rebuilt for https://fedoraproject.org/wiki/Fedora_20_Mass_Rebuild

* Tue Jul 30 2013 Petr Machata <pmachata@redhat.com> - 3.5.2-3
- Rebuild for boost 1.54.0

* Mon Jun 17 2013 Morten Stevens <mstevens@imt-systems.com> - 3.5.2-2
- Added support for lua 5.2

* Mon Jun 10 2013 Morten Stevens <mstevens@imt-systems.com> - 3.5.2-1
- Update to 3.5.2

* Fri May 03 2013 Morten Stevens <mstevens@imt-systems.com> - 3.5.1-1
- Update to 3.5.1

* Mon Apr 22 2013 Morten Stevens <mstevens@imt-systems.com> - 3.5-2
- Disarm dead code that causes gcc crashes on ARM (rhbz#954192)

* Mon Apr 15 2013 Morten Stevens <mstevens@imt-systems.com> - 3.5-1
- Update to 3.5
- Fixes CVE-2012-1193 and another variant of the attack (rhbz#794965)
- D.ROOT-SERVERS.NET has a new IP (rhbz#917347)

* Tue Apr 09 2013 Morten Stevens <mstevens@imt-systems.com> - 3.5-0.3.rc5
- Update to 3.5-rc5

* Fri Apr 05 2013 Morten Stevens <mstevens@imt-systems.com> - 3.5-0.2.rc4
- Update to 3.5-rc4

* Tue Mar 05 2013 Morten Stevens <mstevens@imt-systems.com> - 3.5-0.1.rc2
- Update to 3.5-rc2

* Tue Mar 05 2013 Ruben Kerkhof <ruben@rubenkerkhof.com> - 3.3-10
- Enable hardened build as per http://fedoraproject.org/wiki/Packaging:Guidelines#PIE
- Fix bogus date in changelog
- Fix typo in gecos field
- Some rpmlint fixes

* Mon Feb 11 2013 Morten Stevens <mstevens@imt-systems.com> - 3.3-9
- Enable PrivateTmp as per http://fedoraproject.org/wiki/Features/ServicesPrivateTmp

* Thu Sep 27 2012 Morten Stevens <mstevens@imt-systems.com> - 3.3-8
- use new systemd rpm macros (rhbz#850267)
- Update systemd unit file

* Fri Jul 20 2012 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 3.3-7
- Rebuilt for https://fedoraproject.org/wiki/Fedora_18_Mass_Rebuild

* Tue Feb 28 2012 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 3.3-6
- Rebuilt for c++ ABI breakage

* Fri Jan 13 2012 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 3.3-5
- Rebuilt for https://fedoraproject.org/wiki/Fedora_17_Mass_Rebuild

* Mon Sep 12 2011 Tom Callaway <spot@fedoraproject.org> - 3.3-4
- convert to systemd

* Tue Feb 08 2011 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 3.3-3
- Rebuilt for https://fedoraproject.org/wiki/Fedora_15_Mass_Rebuild

* Wed Sep 29 2010 jkeating - 3.3-2
- Rebuilt for gcc bug 634757

* Sat Sep 25 2010 Ruben Kerkhof <ruben@rubenkerkhof.com> 3.3-1
- Upstream released new version: http://doc.powerdns.com/changelog.html

* Thu May 13 2010 Ruben Kerkhof <ruben@rubenkerkhof.com> 3.2-2
- Correct group name (bz #591214)

* Sun Mar 14 2010 Ruben Kerkhof <ruben@rubenkerkhof.com> 3.2-1
- Upstream released new version
- Adjust scriptlets to packaging guidelines

* Mon Mar 01 2010 Ruben Kerkhof <ruben@rubenkerkhof.com> 3.2-0.1.rc2
- Upstream released new version

* Wed Jan 06 2010 Ruben Kerkhof <ruben@rubenkerkhof.com> 3.1.7.2-1
- Upstream released new version
- Fixes CVE-2009-4009 and CVE-2009-4010

* Tue Nov 24 2009 Ruben Kerkhof <ruben@rubenkerkhof.com> 3.1.7.1-3
- Start recursor earlier in the boot process (#540428)

* Mon Aug 10 2009 Ruben Kerkhof <ruben@rubenkerkhof.com> - 3.1.7.1-2
- Re-add accidently dropped patch (#516562)

* Mon Aug 03 2009 Ruben Kerkhof <ruben@rubenkerkhof.com> - 3.1.7.1-1
- Upstream released new version
- Drop patches included upstream

* Sat Jul 25 2009 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 3.1.7-5
- Rebuilt for https://fedoraproject.org/wiki/Fedora_12_Mass_Rebuild

* Fri Feb 27 2009 Ruben Kerkhof <ruben@rubenkerkhof.com> - 3.1.7-4
- Fix errors with newer Boost
- Fix build with gcc4.4

* Thu Feb 26 2009 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 3.1.7-3
- Rebuilt for https://fedoraproject.org/wiki/Fedora_11_Mass_Rebuild

* Thu Jul 24 2008 Ruben Kerkhof <ruben@rubenkerkhof.com> - 3.1.7-2
- Use OPTFLAGS because CXXFLAGS overrides the defaults

* Thu Jul 24 2008 Ruben Kerkhof <ruben@rubenkerkhof.com> - 3.1.7-1
- Upstream released new version, now with Lua support

* Sun May 11 2008 Ruben Kerkhof <ruben@rubenkerkhof.com> - 3.1.6
- Upstream released new version

* Wed Apr 02 2008 Ruben Kerkhof <ruben@rubenkerkhof.com> - 3.1.5
- Upstream released new version

* Sat Feb 16 2008 Ruben Kerkhof <ruben@rubenkerkhof.com> - 3.1.5-0.1.snapshot4
- Snapshot 4
- Drop gcc 4.3 patch, fixed upstream

* Sat Feb 09 2008 Ruben Kerkhof <ruben@rubenkerkhof.com> - 3.1.5-0.1.snapshot3
- Sync with upstream
- Compile fixes for gcc43

* Sat Jan 27 2007 <ruben@rubenkerkhof.com> 3.1.4-4
- Now really fix the description in init script

* Sat Jan 27 2007 <ruben@rubenkerkhof.com> 3.1.4-3
- Fixed Description in init script

* Wed Jan 24 2007 <ruben@rubenkerkhof.com> 3.1.4-2
- Fixes per bz review 221188:
- Changed user to pdns-recursor
- Patched the Makefile to not strip debugsymbols
- Skipped the configure step, it didn't do much
- Added a more Fedora-centric initscript
- Use condrestart instead of restart in %%postun

* Sun Dec 31 2006 <ruben@rubenkerkhof.com> 3.1.4-1
- Initial import
